import nltk #line:1
from nltk .corpus import stopwords #line:2
from nltk .tokenize import word_tokenize #line:3
from nltk .tag import pos_tag #line:4
from pydantic import BaseModel #line:5
from faker import Faker #line:6
import os #line:7
import pandas as pd #line:8
import json #line:9
import random #line:10
nltk .download ('averaged_perceptron_tagger')#line:12
nltk .download ('punkt')#line:13
nltk .download ('stopwords')#line:14
class textAnonyms (BaseModel ):#line:17
    originalText :str #line:18
    textFormat :str #line:19
stop_words =set (stopwords .words ('french'))#line:22
liste_pays =["afghanistan","afrique du sud","albanie","algérie","allemagne","andorre","angola","antigua-et-barbuda","arabie saoudite","argentine","arménie","aruba","australie","autriche","azerbaïdjan","bahamas","bahreïn","bangladesh","barbade","belgique","belize","bélarus","bénin","bhoutan","birmanie","bolivie","bosnie-herzégovine","botswana","brésil","brunéi","bulgarie","burkina faso","burundi","cambodge","cameroun","canada","cap-vert","chili","chine","chypre","colombie","comores","corée du nord","corée du sud","costa rica","côte d'ivoire","croatie","cuba","curaçao","danemark","djibouti","dominique","egypte","el salvador","émirats arabes unis","équateur","érythrée","espagne","estonie","éthiopie","fidji","finlande","france","gabon","gambie","géorgie","ghana","grèce","grenade","guatemala","guinée","guinée équatoriale","guinée-bissau","guyana","haïti","honduras","hongrie","inde","indonésie","irak","iran","irlande","islande","israël","italie","jamaïque","japon","jordanie","kazakhstan","kenya","kirghizistan","kiribati","kosovo","koweït","laos","lesotho","lettonie","liban","libéria","libye","liechtenstein","lituanie","luxembourg","macédoine du nord","madagascar","malaisie","malawi","maldives","mali","malte","maroc","marshall","maurice","mauritanie","mexique","micronésie","moldavie","monaco","mongolie","monténégro","mozambique","namibie","nauru","nepal","nicaragua","niger","nigeria","niue","norvège","nouvelle-zélande","oman","ouganda","ouzbékistan","pakistan","palaos","panama","papouasie nouvelle-guinée","paraguay","pays-bas","pérou","philippines","pologne","portugal","qatar","république centrafricaine","république démocratique du congo","république dominicaine","république du congo","république tchèque","roumanie","royaume-uni","russie","rwanda","saint-christophe-et-niévès","saint-marin","saint-martin","saint-vincent-et-les-grenadines","sainte-lucie","salomon","salvador","samoa","são tomé-et-principe","sénégal","serbie","seychelles","sierra leone","singapour","slovaquie","slovénie","somalie","soudan","soudan du sud","sri lanka","suède","suisse","surinam","swaziland","syrie","tadjikistan","tanzanie","tchad","thaïlande","timor oriental","togo","tonga","trinité-et-tobago","tunisie","turkménistan","turquie","tuvalu","ukraine","uruguay","vanuatu","vatican","venezuela","vietnam","yémen","zambie","zimbabwe"]#line:23
faker =Faker (["fr_FR"])#line:24
def anonymiser_mot (OO0000O0O0000O0OO :textAnonyms ):#line:29
    try :#line:30
        O00OOO0O000O00O0O =pd .read_csv ("words.csv",dtype ={"original":str ,"anonymous":str })#line:31
        if (OO0000O0O0000O0OO .originalText =="FM"):#line:33
            OOO0O0OOOOOOOOO00 ="DAB+"#line:34
        elif (OO0000O0O0000O0OO .originalText =="DAB+"):#line:35
            OOO0O0OOOOOOOOO00 ="FM"#line:36
        elif (OO0000O0O0000O0OO .originalText .lower ()=="iqoya"):#line:37
            OOO0O0OOOOOOOOO00 ="codec audio"#line:38
        elif (OO0000O0O0000O0OO .textFormat =="PERSON"):#line:39
            if (cherche_ville (OO0000O0O0000O0OO .originalText .upper ())):#line:41
                OOO0O0OOOOOOOOO00 =random .choice (["TOULON","NANTES","MONTPELLIER","CHAMBOURCY","NANTERRE","GRENOBLE","LYON"])#line:42
            elif (cherche_chaine (OO0000O0O0000O0OO .originalText .upper ())):#line:43
                OOO0O0OOOOOOOOO00 =random .choice (["TF1","M6","BFMTV" "FRANCE5","FRANCE2"])#line:44
            else :#line:45
                OOO0O0OOOOOOOOO00 =random .choice (["PAUL","JEAN","PHILIPPE","PIERRE","MARC","DAVID","GUILLAUME"])#line:46
        elif (OO0000O0O0000O0OO .textFormat =="DATE"):#line:47
            OOO0O0OOOOOOOOO00 =faker .date ()#line:48
        elif (OO0000O0O0000O0OO .textFormat =="LOCATION"):#line:49
            OOO0O0OOOOOOOOO00 =faker .address ()#line:50
        elif (OO0000O0O0000O0OO .textFormat =="NUMBER"):#line:51
            if (int (OO0000O0O0000O0OO .originalText )<24 ):#line:52
                OOO0O0OOOOOOOOO00 =faker .numerify (text ='#')#line:53
            else :#line:54
                OOO0O0OOOOOOOOO00 =str (faker .random_int (min =0 ,max =(int (OO0000O0O0000O0OO .originalText )-1 )))#line:55
        elif (OO0000O0O0000O0OO .textFormat =="COUNTRY"):#line:56
            OOO0O0OOOOOOOOO00 =faker .country ()#line:57
        elif (OO0000O0O0000O0OO .textFormat =="ORGANIZATION"):#line:58
            OOO0O0OOOOOOOOO00 =random .choice (["ORANGE","SAFRAN","BOUYGUES","FREE"])#line:59
        while any (O00OOO0O000O00O0O ["anonymous"]==OOO0O0OOOOOOOOO00 ):#line:63
            OOO0O0OOOOOOOOO00 =faker .first_name ()#line:64
        O00OOO0O000O00O0O =pd .concat ([O00OOO0O000O00O0O ,pd .DataFrame ([[OO0000O0O0000O0OO .originalText ,OOO0O0OOOOOOOOO00 ]],columns =["original","anonymous"])])#line:66
        O00OOO0O000O00O0O .to_csv ("words.csv",index =False )#line:67
        return OOO0O0OOOOOOOOO00 #line:69
    except Exception as O00000O0OOOOO0O0O :#line:70
        return OO0000O0O0000O0OO .originalText #line:71
def cherche_chaine (OOO0O0O0000OOOOOO ):#line:74
    OOO0O0O0000OOOOOO =OOO0O0O0000OOOOOO .upper ()#line:75
    OOOOO0OOOO000OO00 =["C8","CNEWS","TF1","M6","CSTAR","BFM","F5"]#line:77
    for OOOO0OO0OO0OOO0OO in OOOOO0OOOO000OO00 :#line:78
        if OOOO0OO0OO0OOO0OO in OOO0O0O0000OOOOOO :#line:79
            return True #line:80
            break #line:81
    return False #line:83
def cherche_ville (O000OO000O00000O0 ):#line:86
    O000OO000O00000O0 =O000OO000O00000O0 .upper ()#line:87
    with open ('../villes.json','r')as OO0OOO0OOOOOOO0O0 :#line:89
        OO000OO00O0O0OOOO =json .load (OO0OOO0OOOOOOO0O0 )#line:90
    for O0O0OO000O000OOO0 in OO000OO00O0O0OOOO :#line:91
        if O000OO000O00000O0 in O0O0OO000O000OOO0 ["Nom_commune"]:#line:92
            return True #line:93
            break #line:94
    return False #line:96
def desanonymiser_mot (OOO0O00OOO0OO000O ):#line:98
    O00O0000O0O0O0O0O =pd .read_csv ("words.csv",dtype ={"original":str ,"anonymous":str })#line:99
    if not O00O0000O0O0O0O0O .empty :#line:100
        O00O000OOOO00OOOO =O00O0000O0O0O0O0O [O00O0000O0O0O0O0O ["anonymous"]==OOO0O00OOO0OO000O ]["original"]#line:101
        if not O00O000OOOO00OOOO .empty :#line:102
            return O00O000OOOO00OOOO .iloc [0 ]#line:103
    return None #line:104
def initialiser ():#line:106
    O00O0O0OO0O0O0OOO ="words.csv"#line:107
    if os .path .exists (O00O0O0OO0O0O0OOO ):#line:109
        os .remove (O00O0O0OO0O0O0OOO )#line:110
    OOO00000O0O0OOOO0 =pd .DataFrame (columns =["original","anonymous"])#line:112
    OOO00000O0O0OOOO0 .to_csv (O00O0O0OO0O0O0OOO ,index =False )#line:114
def anonymiser_paragraphe (OOOO00O000O000O00 ):#line:119
    OO0OO0O0OOOOOO000 =OOOO00O000O000O00 #line:121
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace (".",". ")#line:122
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace (",",", ")#line:123
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("0H","0 H")#line:124
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("1H","1 H")#line:125
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("2H","2 H")#line:126
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("3H","3 H")#line:127
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("4H","4 H")#line:128
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("5H","5 H")#line:129
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("6H","6 H")#line:130
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("7H","7 H")#line:131
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("8H","8 H")#line:132
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("9H","9 H")#line:133
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("0F","0 F ")#line:134
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("1F","1 F ")#line:135
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("2F","2 F ")#line:136
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("3F","3 F ")#line:137
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("4F","4 F ")#line:138
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("5F","5 F ")#line:139
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("6F","6 F ")#line:140
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("7F","7 F ")#line:141
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("8F","8 F ")#line:142
    OO0OO0O0OOOOOO000 =OO0OO0O0OOOOOO000 .replace ("9F","9 F ")#line:143
    OO0OOOO0O00O0O000 =word_tokenize (OO0OO0O0OOOOOO000 ,language ="french")#line:145
    O00O00OO000000OO0 =pos_tag (OO0OOOO0O00O0O000 )#line:146
    O0O00000000O0OO0O =[]#line:147
    O00OO000OOO00O000 =set (stopwords .words ('french'))#line:149
    O0O00O0O0O000O0O0 =["h","mon","ma","HF","mes","ton","ta","tes","son","sa","ses","notre","votre","leur","leurs","merci","alors","fh","hf","intervention","j'ai","télégéstion","télégestion","absence","énergie","radio"]#line:150
    O00OO000OOO00O000 .update (O0O00O0O0O000O0O0 )#line:151
    O0OOOO00OO00O00O0 =0 #line:152
    for O0OO00OO00O000O00 ,O00OO00O0O0O0O00O in O00O00OO000000OO0 :#line:153
        O0OOOO00OO00O00O0 =O0OOOO00OO00O00O0 +1 #line:154
        if O0OO00OO00O000O00 .lower ()in liste_pays :#line:155
            O0O00000000O0OO0O .append (("COUNTRY",O0OO00OO00O000O00 ))#line:156
        elif O00OO00O0O0O0O00O =="NNP"and "DS"in O0OO00OO00O000O00 or "LA"in O0OO00OO00O000O00 :#line:157
            O0O00000000O0OO0O .append (("NUMBER",O0OO00OO00O000O00 ))#line:158
        elif O00OO00O0O0O0O00O =="NNP"and O0OO00OO00O000O00 .isupper ()and O0OO00OO00O000O00 .lower ()not in O00OO000OOO00O000 and len (O0OO00OO00O000O00 )>1 :#line:159
            O0O00000000O0OO0O .append (("ORGANIZATION",O0OO00OO00O000O00 ))#line:160
        elif O00OO00O0O0O0O00O =="NNP"and O0OO00OO00O000O00 .lower ()not in O00OO000OOO00O000 and O0OOOO00OO00O00O0 >1 and len (O0OO00OO00O000O00 )>1 :#line:161
            O0O00000000O0OO0O .append (("PERSON",O0OO00OO00O000O00 ))#line:162
        elif O00OO00O0O0O0O00O =="CD"and "/"in O0OO00OO00O000O00 :#line:163
            O0O00000000O0OO0O .append (("DATE",O0OO00OO00O000O00 ))#line:164
        elif O00OO00O0O0O0O00O =="CD"and ":"not in O0OO00OO00O000O00 :#line:165
            O0O00000000O0OO0O .append (("NUMBER",O0OO00OO00O000O00 ))#line:166
        elif O00OO00O0O0O0O00O =="NNP"and O0OO00OO00O000O00 .lower ()not in O00OO000OOO00O000 and O0OOOO00OO00O00O0 >1 and len (O0OO00OO00O000O00 )>1 :#line:167
            O0O00000000O0OO0O .append (("LOCATION",O0OO00OO00O000O00 ))#line:168
    for OO00OOO0OOO0OOO0O ,OO00O000O0OO0O00O in O0O00000000O0OO0O :#line:172
        OOOOO00O00O0OO000 =textAnonyms (originalText =OO00O000O0OO0O00O ,textFormat =OO00OOO0OOO0OOO0O )#line:173
        OOOO00O000O000O00 =OOOO00O000O000O00 .replace (OO00O000O0OO0O00O ,anonymiser_mot (OOOOO00O00O0OO000 ))#line:174
    OOOO00O000O000O00 =OOOO00O000O000O00 .replace ("-","/")#line:176
    OOOO00O000O000O00 =OOOO00O000O000O00 .replace (" / "," - ")#line:177
    return OOOO00O000O000O00 #line:178
def desanonymiser_paragraphe (OO000OOOO00O0O00O ):#line:180
    OOO0OOOOO00000OOO =pd .read_csv ("words.csv",dtype ={"original":str ,"anonymous":str })#line:183
    for OO0OO0000OOOO0000 ,O000000OO000000O0 in OOO0OOOOO00000OOO .iterrows ():#line:184
        OO000OOOO00O0O00O =OO000OOOO00O0O00O .replace (O000000OO000000O0 ["anonymous"],O000000OO000000O0 ["original"])#line:186
    return OO000OOOO00O0O00O #line:187



from setuptools import setup, find_packages

setup(
    name='tdf.labnum.tdfAnonymizer',
    version='0.3',
    packages=find_packages(),
    data_files=[('.', ['villes.json'])],  # Ajoutez le chemin vers votre fichier JSON
    install_requires=[
        'nltk',
        'pydantic',
        'faker',
        'pandas'
    ],
)
